==> datavan-4.2.1.tgz: package/lib/es6/db-util.js <==
import _omit from "lodash/omit";
import _pick from "lodash/pick";
import _map from "lodash/map";
import _each from "lodash/each";

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import createDb from './db';
var parentDataMutation = ['preloads', 'fetchAts'];
export var forkDb = function forkDb(parentDb) {
  var confs = parentDb.getConfig();
  var newDb = createDb(confs); // copy submits and originals

  _each(confs, function (conf, name) {
    newDb[name].submits = _objectSpread({}, parentDb[name].submits);
    newDb[name].originals = _objectSpread({}, parentDb[name].originals);
  }); // subscribe parent change to child db change


  parentDb.subscribe(function (change) {
    _each(change, function (coll, name) {
      newDb[name]._cache = {};
    });

    return newDb.emit(change);
  });
  return Object.assign(newDb, {
    getParent: function getParent() {
      return parentDb;
    },
    getFetchData: function getFetchData(name) {
      return parentDb.getDb()[name];
    },
    dispatchFilter: function dispatchFilter(mutSpecs) {
      var parentMuts = [];

      var newSpecs = _map(mutSpecs, function (mutSpec) {
        var name = mutSpec.name,
            mutation = mutSpec.mutation;

        if (mutation.preloads || mutation.fetchAts) {
          parentMuts.push({
            name: name,
            mutation: _pick(mutation, parentDataMutation)
          });
          return {
            name: name,
            mutation: _omit(mutation, parentDataMutation)
          };
        }

        return mutSpec;
      });

      if (parentMuts.length > 0) {
        parentDb.dispatch(parentMuts);
      }

      return newSpecs;
    }
  });
};

==> datavan-4.2.5.tgz: package/lib/es6/db-util.js <==
import _omit from "lodash/omit";
import _pick from "lodash/pick";
import _map from "lodash/map";
import _mapValues from "lodash/mapValues";
import _each from "lodash/each";

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import createDb from './db';
var parentDataMutation = ['preloads', 'fetchAts', 'fetchingAt', '_fetchResults', '_byIdAts'];
export var forkDb = function forkDb(parentDb) {
  var confs = parentDb.getConfig();
  var subDb = createDb(confs); // copy submits and originals

  _each(confs, function (conf, name) {
    subDb[name].submits = _objectSpread({}, parentDb[name].submits);
    subDb[name].originals = _objectSpread({}, parentDb[name].originals);
  }); // subscribe parent change to child db change


  parentDb.subscribe(function (parentChange) {
    // re-emit parent change event by ...
    var subChange = _mapValues(parentChange, function (coll, name) {
      return (// create new instance and clear _cache
        _objectSpread({}, subDb[name], {
          _cache: {}
        })
      );
    });

    Object.assign(subDb, subChange);
    subDb.emit(subChange);
  });
  return Object.assign(subDb, {
    getParent: function getParent() {
      return parentDb;
    },
    getFetchData: function getFetchData(name) {
      return parentDb.getDb()[name];
    },
    dispatchFilter: function dispatchFilter(mutSpecs) {
      var parentMuts = [];

      var newSpecs = _map(mutSpecs, function (mutSpec) {
        var name = mutSpec.name,
            mutation = mutSpec.mutation; // TODO separate/handle $merge, $toggle, $unset

        if (parentDataMutation.find(function (key) {
          return mutation[key];
        })) {
          parentMuts.push({
            name: name,
            mutation: _pick(mutation, parentDataMutation)
          });
          return {
            name: name,
            mutation: _omit(mutation, parentDataMutation)
          };
        }

        return mutSpec;
      });

      if (parentMuts.length > 0) {
        parentDb.dispatch(parentMuts);
      }

      return newSpecs;
    }
  });
};
